@@ -52,13 +52,6 @@ typedef struct {
 	int kill;
 } GOptionData;
 
-enum {
-	LOADING_INFO,
-	DEBUGGING,
-	SENDING,
-	DONE
-};
-
 enum {
 	BUG_TYPE_CRASH,
 	BUG_TYPE_REQUEST
