@@ -27,7 +27,22 @@
 #include "bug-buddy.h"
 #include "distribution.h"
 
-#define d(x)
+typedef struct _Package      Package;
+typedef struct _Phylum       Phylum;
+typedef struct _Distribution Distribution;
+
+typedef char *(*DistroVersionFunc) (Distribution *distro);
+
+struct _Phylum {
+	DistroVersionFunc version;
+};
+
+
+struct _Distribution {
+	char *name;
+	char *version_file;
+	Phylum *phylum;
+};
 
 static char *get_lsb_version (Distribution *distro);
 static char *get_redhat_version (Distribution *distro);
@@ -55,13 +70,27 @@ Phylum irix_phy = {
 	get_irix_version
 };
 
-
 DistroVersionFunc lsb_ver =  get_lsb_version;
 DistroVersionFunc redhat_ver = get_redhat_version;
 DistroVersionFunc turbolinux_ver = get_turbolinux_version;
 DistroVersionFunc debian_ver = get_debian_version;
 DistroVersionFunc irix_ver =  get_irix_version;
 
+static Distribution distros[] = {
+	{ "Slackware",     "/etc/slackware-version",  &debian_phy },
+	{ "Mandrake",      "/etc/mandrake-release",   &redhat_phy },
+	{ "TurboLinux",    "/etc/turbolinux-release", &turbolinux_phy },
+	{ "SuSE",          "/etc/SuSE-release",       &redhat_phy },
+	{ "Red Hat",       "/etc/redhat-release",     &redhat_phy },
+	{ "Fedora",        "/etc/fedora-release",     &redhat_phy },
+	{ "Gentoo",        "/etc/gentoo-release",     &redhat_phy },
+	{ "Solaris",       "/etc/release",  	      &redhat_phy },
+	{ "LSB Linux",     "/etc/lsb-release",        &lsb_phy },
+	{ "Debian",        "/etc/debian_version",     &debian_phy },
+	{ "IRIX Freeware", "/bin/hinv",               &irix_phy },
+	{ NULL }
+};
+
 
 static char**
 get_lines_from_file (const char *filename)
@@ -72,7 +101,7 @@ get_lines_from_file (const char *filename)
 	GError *error = NULL;
 	
 	if (!g_file_get_contents (filename, &contents, &length, &error)) {
-		g_free (error);
+		g_error_free (error);
 		return NULL;
 	}
 
@@ -183,7 +212,7 @@ get_irix_version (Distribution *distro)
 				      "versions -b fw_common | awk 'NR >= 4 { print \", Freeware\",$3 }'");*/
 }
 
-char *
+static char *
 get_distro_name_from_file (void)
 {
 	int i;
